@@ -205,8 +205,6 @@ show.Xfgpm <- function(object) {
 #' @param par.clust an optional parallel processing cluster created with the \code{\link[parallel]{makeCluster}}
 #'   function of the \link[=parallel]{parallel package}. If not provided, structural configurations are evaluated in
 #'   sequence.
-#' @param trace an optional boolean indicating if control messages regarding the optimization of the hyperparameters
-#'   should be printed to console. Default is FALSE.
 #' @param pbars an optional boolean indicating if progress bars should be displayed. Default is TRUE.
 #'
 #' @return An object of class \linkS4class{Xfgpm} containing the data structures linked to the structural optimization
@@ -238,6 +236,7 @@ show.Xfgpm <- function(object) {
 #'
 #' @seealso \strong{*} \link[funGp]{plotX} for diagnostic plots for a fgpm_factory output and selected model;
 #' @seealso \strong{*} \link[funGp]{plotEvol} for a plot of the evolution of the model selection algorithm in fgpm_factory;
+#' @seealso \strong{*} \link[funGp]{get_active_in} for post-processing of input data structures following a fgpm_factory call;
 #' @seealso \strong{*} \link[funGp]{predict} for predictions based on a funGp model;
 #' @seealso \strong{*} \link[funGp]{simulate} for simulations based on a funGp model;
 #' @seealso \strong{*} \link[funGp]{update} for post-creation updates on a funGp model.
@@ -393,6 +392,15 @@ show.Xfgpm <- function(object) {
 #' cl <- parallel::makeCluster(2)
 #' xm.par <- fgpm_factory(sIn = sIn, fIn = fIn, sOut = sOut, par.clust = cl) #  (~260 seconds)
 #' parallel::stopCluster(cl)
+#'
+#' # NOTE: in order to provide progress bars for the monitoring of time consuming processes
+#' #       ran in parallel, funGp relies on the doFuture and future packages. Parallel processes
+#' #       suddenly interrupted by the user tend to leave corrupt connections. This problem is
+#' #       originated outside funGp, which limits our control over it. On section 4.1 of the
+#' #       of funGp, we provide a temporary solution to the issue and we remain attentive in
+#' #       case it appears a more elegant way to handle it or a manner to suppress it.
+#' #
+#' #       funGp manual: https://hal.archives-ouvertes.fr/hal-02536624
 #' }
 #'
 #' @importFrom methods new
@@ -401,7 +409,7 @@ show.Xfgpm <- function(object) {
 fgpm_factory <- function(sIn = NULL, fIn = NULL, sOut = NULL, ind.vl = NULL,
                           ctraints = list(), setup = list(), time.lim = Inf,
                           nugget = 1e-8, n.starts = 1, n.presample = 20,
-                          par.clust = NULL, trace = FALSE, pbars = TRUE) {
+                          par.clust = NULL, pbars = TRUE) {
 
   # launch timer
   time.str <- Sys.time()
@@ -420,7 +428,7 @@ fgpm_factory <- function(sIn = NULL, fIn = NULL, sOut = NULL, ind.vl = NULL,
   }
 
   # optimize model structure
-  opt <- master_ACO(sIn, fIn, sOut, ind.vl, solspace, setup, extargs, time.str, time.lim, trace, pbars, par.clust)
+  opt <- master_ACO(sIn, fIn, sOut, ind.vl, solspace, setup, extargs, time.str, time.lim, pbars, par.clust)
   X.model <- new("Xfgpm")
   X.model@factoryCall@string <- gsub("^ *|(?<= ) | *$", "", paste0(deparse(match.call()), collapse = " "), perl = TRUE)
   X.model@model <- opt$model
@@ -479,7 +487,6 @@ setSpace <- function(sIn, fIn, ctraints) {
     if (!is.null(f_keepOn)) f.state[f_keepOn] <- 1
 
     # update the set of potential dimensions for functional inputs
-    # browser()
     if (!is.null(f_fixDims)) {
       for (i in ncol(f_fixDims)) {
         f.dims[[f_fixDims[1,i]]] <- f_fixDims[2,i]
@@ -610,22 +617,24 @@ getSpacesize <- function(space) {
   k.type <- space$k.type
 
   # count 2 levels for each free scalar input
-  n.s <- 2 * sum(s.state == 0)
+  n.s <- max(2 * sum(s.state == 0),1)
 
   # count for functional inputs
   n.fs <- rep(1, space$df)
-  for (i in 1:space$df) {
-    # count the number of distance types
-    n.fs[i] <- n.fs[i] * length(f.dist[[i]])
+  if (space$df > 0) {
+    for (i in 1:space$df) {
+      # count the number of distance types
+      n.fs[i] <- n.fs[i] * length(f.dist[[i]])
 
-    # count the number of dimensions
-    n.fs[i] <- n.fs[i] * length(f.dims[[i]])
+      # count the number of dimensions
+      n.fs[i] <- n.fs[i] * length(f.dims[[i]])
 
-    # count the number of bases
-    n.fs[i] <- n.fs[i] * length(f.bas[[i]])
+      # count the number of bases
+      n.fs[i] <- n.fs[i] * length(f.bas[[i]])
 
-    # if the input is free, add an extra level for the function inactive
-    if (f.state[i] == 0) n.fs[i] <- n.fs[i] + 1
+      # if the input is free, add an extra level for the function inactive
+      if (f.state[i] == 0) n.fs[i] <- n.fs[i] + 1
+    }
   }
   n.f <- prod(n.fs)
 
